# Slot: title


the official title of the schema

URI: [http://w3id.org/biolink/biolinkml/meta/title](slot_uri)
## Domain and Range

[SchemaDefinition](SchemaDefinition.md) -><sub>opt</sub> [String](String.md)
## Inheritance

## Children

## Used by

 * [SchemaDefinition](SchemaDefinition.md)
